'use client'
import { login, signup } from '@/server/actions/auth';
import { zodResolver } from '@hookform/resolvers/zod';
import { useForm } from 'react-hook-form';
import { z } from 'zod';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import {
  Form,
  FormField,
  FormControl,
  FormDescription,
  FormLabel,
  FormMessage,
  FormItem,
} from '@/components/ui/form';
import { useRef } from 'react';

const formSchema = z.object({
  fullName: z.string().optional(),
  email: z.string().email("Must be a valid email!"),
  password: z.string().min(8, "Must be at least 8 characters!"),
});

const LoginForm = () => {
  const formRef = useRef<HTMLFormElement>(null);
  
  const form = useForm<z.infer<typeof formSchema>>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      fullName: '',
      email: '',
      password: '',
    },
  });

  // Create wrapper functions for the server actions
  const handleLogin = async () => {
    if (await form.trigger()) {
      const formData = new FormData(formRef.current!);
      await login(formData);
    }
  };

  const handleSignup = async () => {
    if (await form.trigger()) {
      const formData = new FormData(formRef.current!);
      await signup(formData);
    }
  };

  return (
    <div className="flex flex-col items-center justify-center">
      <Form {...form}>
        <form ref={formRef} className="space-y-4">
          <FormField
            control={form.control}
            name="fullName"
            render={({ field }) => (
              <FormItem>
                <FormLabel htmlFor='fullName'>
                  Full Name
                </FormLabel>
                <FormControl>
                  <Input id='fullName' type='text' {...field} />
                </FormControl>
                <FormDescription>
                  Full name is only required when signing up.
                </FormDescription>
                <FormMessage />
              </FormItem>
            )}
          />
          <FormField
            control={form.control}
            name="email"
            render={({ field }) => (
              <FormItem>
                <FormLabel htmlFor='email'>
                  Email
                </FormLabel>
                <FormControl>
                  <Input id='email' type='email' {...field} required />
                </FormControl>
                <FormMessage />
              </FormItem>
            )}
          />
          <FormField
            control={form.control}
            name="password"
            render={({ field }) => (
              <FormItem>
                <FormLabel>
                  Password
                </FormLabel>
                <FormControl>
                  <Input id='password' type='password' {...field} required />
                </FormControl>
                <FormMessage />
              </FormItem>
            )}
          />
          <div className="flex gap-4 pt-2">
            <Button type="button" onClick={handleLogin}>
              Log in
            </Button>
            <Button type="button" onClick={handleSignup}>
              Sign up
            </Button>
          </div>
        </form>
      </Form>
    </div>
  );
};

export default LoginForm;
